within ;
package SimpleFluids
  package Interfaces
    connector SFluid
      Real p(unit="Pa") "Pressure";
      flow Real m_flow(unit="kg/s") "Total mass of solvent";
      stream Real c(unit="mol/kg") "Concentration";
    end SFluid;
  end Interfaces;

  model Kadinka

    Interfaces.SFluid sFluid
      annotation (Placement(transformation(extent={{88,-10},{108,10}})));

  parameter Real pressure(unit="Pa") "Pressure";
  Real mass(unit="kg", start=10) "Mass of solvent";
  Real solute(unit="mol", start=1) "Mass of solute";

  equation
    der(mass)= sFluid.m_flow;
    der(solute)= if ( sFluid.m_flow < 0) then
                          sFluid.m_flow * sFluid.c
   else sFluid.m_flow * inStream(sFluid.c);

    sFluid.c = solute/mass;
    sFluid.p = pressure;
  end Kadinka;

  model Resistor

    Interfaces.SFluid p
      annotation (Placement(transformation(extent={{-106,0},{-86,20}})));
    Interfaces.SFluid n
      annotation (Placement(transformation(extent={{86,0},{106,20}})));
    annotation (Diagram(graphics));
    parameter Real R "Resistance";
  equation
    p.m_flow + n.m_flow = 0;
    p.p - n.p = R*p.m_flow;
    p.c = if (p.m_flow>0) then inStream(p.c) else n.c;
    n.c = if (p.m_flow>0) then p.c else inStream(n.c);
  end Resistor;

  model Test
    Kadinka kadinka(pressure=2, solute(start=0.1))
      annotation (Placement(transformation(extent={{-82,26},{-62,46}})));
    Resistor resistor(R=0.01)
      annotation (Placement(transformation(extent={{-30,22},{-10,42}})));
    Kadinka kadinka1(pressure=1)
      annotation (Placement(transformation(extent={{30,26},{50,46}})));
  equation
    connect(kadinka.sFluid, resistor.p) annotation (Line(
        points={{-62.2,36},{-44,36},{-44,33},{-29.6,33}},
        color={0,0,255},
        smooth=Smooth.None));
    connect(resistor.n, kadinka1.sFluid) annotation (Line(
        points={{-10.4,33},{19.8,33},{19.8,36},{49.8,36}},
        color={0,0,255},
        smooth=Smooth.None));
    annotation (Diagram(graphics));
  end Test;
  annotation (uses(Modelica(version="3.2")));
end SimpleFluids;
